netapp_ontap.models.flexcache_relationship API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.flexcache_relationship`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FlexcacheRelationshipSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FlexcacheRelationship object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster: Cluster GET`

    The cluster field of the flexcache_relationship.

  `create_time: ImpreciseDateTime GET`

    Creation time of the relationship.

    Example: 2018-06-04T19:00:00.000+0000

  `ip_address: str GET`

    Cluster management IP of the remote cluster.

    Example: 10.10.10.7

  `size: Size GET`

    Size of the remote volume.

  `state: str GET`

    Volume state

    Valid choices:

    - error
    - mixed
    - offline
    - online
  `svm: Svm GET POST`

    The svm field of the flexcache_relationship.

  `volume: Volume GET POST PATCH`

    The volume field of the flexcache_relationship.